+++
title = "Paragraphs in lists"
tags = ["lists", "paragraph"]
draft = false
+++

-   Bullet lists can have paragraphs or block elements within them.

    Just indent the content to be even with the text of the bullet
    point, rather than the bullet itself.

    ```shell
    ls -l
    ```
-   Here's the second bullet item.

    Paragraph 1 in second bullet.

    Paragraph 2 in second bullet.

Paragraph outside the list.
